@@ -70,7 +70,7 @@ use strict;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 use vars qw(%root %multi %match %akin);
 
-$VERSION=     '1.15';
+$VERSION=     '1.16';
 @ISA=         qw(Exporter);
 @EXPORT=      qw(nickname_eq nickroot);
 @EXPORT_OK=   qw(nickmatch nickfollow);
@@ -168,6 +168,8 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   Albertine => 'Alberta',
   Alec => 'Alexander',
   Alexandra => 'Alexandria',
+  Alexei => 'Alexander',
+  Alexey => 'Alexander',
   Alf => 'Alfred',
   Alice => 'Elsie',
   Alicia => 'Alice',
@@ -183,6 +185,9 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   Anabelle => 'Arabella',
   Ander => 'Anderson',
   Andre => 'Anderson',
+  Andreas => 'Andrew',
+  Andrei => 'Andrew',
+  Andrey => 'Andrew',
   Andria => 'Andrea',
   AngE => 'Angela',
   Angelica => 'Angela',
@@ -315,6 +320,7 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   CheslE => 'Chesley',
   Chet => 'Chesley',
   Chick => 'Charles',
+  Chip => 'Charles',
   ChristE => 'Christiana',
   Christian => 'Christopher',
   Christina => 'Christiana',
@@ -507,15 +513,19 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   Frankisek => 'Francis',
   Franklin => 'Francis',
   Franz => 'Francis',
+  Frederik => 'Frederick',
   Fredric => 'Frederick',
   Fredricka => 'Frederica',
+  Fredrik => 'Frederick',
   Frish => 'Frederick',
+  Frits => 'Frederick',
   Fritz => 'Frederick',
   Frona => 'Sophronia',
   Fronia => 'Sophronia',
   Gabe => 'Gabriel',
   Gabriella => 'Gabrielle',
   Gail => 'Abigail',
+  Garry => 'Gary',
   GatsE => 'Augustus',
   GatsbE => 'Augustus',
   GattE => 'Gertrude',
@@ -557,6 +567,7 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   HelmE => 'Wilhelmina',
   Hen => 'Henry',
   Hence => 'Henry',
+  Henk => 'Hendrick',
   Hephsibah => 'Hepsabah',
   HepsE => 'Hepsabah',
   Hepsabel => 'Hepsabah',
@@ -734,7 +745,7 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   Len => 'Leonard',
   Lenhart => 'Leonard',
   LennE => 'Leonard',
-  Leo => 'Leonard',
+  Leonida => 'Leonidas',
   Leonora => 'Eleanor',
   LessE => 'Celeste',
   Lester => 'Leslie',
@@ -807,6 +818,7 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   MamE => 'Mary',
   Manda => 'Amanda',
   Manuel => 'Emanuel',
+  Marc => 'Marcus',
   Marcia => 'Mary',
   MargE => 'Margaret',
   Margaret => 'Gretchen',
@@ -907,6 +919,8 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   NibbE => 'Isabella',
   NicE => 'Vernisee',
   Nicodemus => 'Nicholas',
+  Nicolas => 'Nicholas',
+  Nicolay => 'Nikolai',
   Nicole => 'Nicolena',
   Nicolene => 'Nicolena',
   Nicolina => 'Nicolena',
@@ -919,6 +933,7 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   NonE => 'Joanna',
   Norah => 'Honora',
   NorbE => 'Norbert',
+  Norm => 'Norman',
   NorrE => 'Honora',
   Nowell => 'Noel',
   Odo => 'Odell',
@@ -995,8 +1010,10 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   RhodE => 'Rhodella',
   Rhoda => 'Rhodella',
   Rian => 'Brian',
+  Ricardo => 'Richard',
   Ricka => 'Frederica',
   Rob => 'Robert',
+  Roberto => 'Robert',
   Robin => 'Robert',
   RoddE => 'Rodney',
   Rodger => 'Roger',
@@ -1004,6 +1021,7 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   Roland => 'Orlando',
   Rolf => 'Rudolphus',
   RollE => 'Roland',
+  Ronaldo => 'Ronald',
   Ronna => 'Veronica',
   Rosabella => 'Isabella',
   Rosable => 'Rosabella',
@@ -1114,8 +1132,9 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   TennE => 'Tennessee',
   TensE => 'Hortense',
   TentE => 'Content',
-  Terence => 'Terrance',
+  Terence => 'Terrence',
   Teresa => 'Theresa',
+  Terrance => 'Terrence',
   TessE => 'Theresa',
   Tessa => 'Theresa',
   Thad => 'Thaddeus',
@@ -1362,6 +1381,7 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   Lee => [qw<Elias Leonora Leroy Levi Shirley>],
   Left => [qw<Eliphalet Lafayette>],
   Lena => [qw<Adaline Aileen Angela Arlene Caroline Darlene Evaline Helena Katherine Madeline Magdelina Selina>],
+  Leo => [qw<Leonard Leonidas>],
   Leon => [qw<Leonard Leonidas Lionel Napoleon>],
   Les => [qw<Leslie Lester>],
   LettE => [qw<Charlotte Letitia>],
@@ -1420,7 +1440,7 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   MontE => [qw<Lamont Montgomery>],
   MorE => [qw<Maurice Seymour>],
   Myra => [qw<Almira Elmira>],
-  Naldo => [qw<Reginald Roland>],
+  Naldo => [qw<Reginald Ronald>],
   Nan => [qw<Anna Hannah Nancy>],
   NancE => [qw<Agnes Anna>],
   NannE => [qw<Anna Hannah Nancy>],
@@ -1471,8 +1491,8 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   RobbE => [qw<Robert Roberta>],
   Rod => [qw<Rodney Roger>],
   Rollo => [qw<Roland Rudolphus>],
-  Ron => [qw<Aaron Cameron Roland Veronica>],
-  RonnE => [qw<Aaron Cameron Roland Veronica>],
+  Ron => [qw<Aaron Cameron Ronald Veronica>],
+  RonnE => [qw<Aaron Cameron Ronald Veronica>],
   RosE => [qw<Euphrosina Roseanne>],
   Rosa => [qw<Rosabella Rosalyn>],
   Rose => [qw<Rosabella Rosalyn Roseanne>],
@@ -1492,7 +1512,7 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   Tad => [qw<Thaddeus Theodore>],
   Ted => [qw<Edmund Edward Theodore>],
   TeddE => [qw<Edward Theodore>],
-  TerrE => [qw<Terrance Theresa>],
+  TerrE => [qw<Terrence Theresa>],
   Tess => [qw<Elizabeth Theresa>],
   Theo => [qw<Theodore Theodosia Theophilus>],
   TillE => [qw<Matilda Temperance Tilford>],
@@ -1540,7 +1560,7 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   Alberta => qr/^((A(bertina|l(bert(a|ine)|l$E))|Bert($E)?|Elbert))$/, # Abertina Albertine All$E Bert Bert$E Elbert
   Alderick => qr/^((Al(derick)?|Rich($E)?))$/, # Al Rich Rich$E
   Aleva => qr/^((Aleva|Lev($E|e)))$/, # Leve Lev$E
-  Alexander => qr/^((A(l(e(c|x(ander)?))?|nd$E)|E(c|leck)|Sa(nd$E|sha)))$/, # Alec Alex And$E Ec Sand$E Al Eleck Sasha
+  Alexander => qr/^((A(l(e(c|x(ander|e[iy])?))?|nd$E)|E(c|leck)|Sa(nd$E|sha)))$/, # Alec Alex Alexey Alexei And$E Ec Sand$E Al Eleck Sasha
   Alexandria => qr/^((Al(ex(andr(a|ia))?|la)|Cass($E|andra)?|El(ic|l$E)|Lexa|Sa(nd($E|ra)|sha)|Xan))$/, # Alla Ell$E Elic Sandra Alexandra Lexa Xan Alex Sand$E Sasha Cassandra Cass Cass$E
   Alfred => qr/^((Al(f($E|red)?)?|Fred(d$E)?))$/, # Al Alf Alf$E Fred Fredd$E
   Alfreda => qr/^((Alf($E|reda)|Fr(ed(a|d$E)|ieda)))$/, # Alf$E Frieda Fredd$E Freda
@@ -1558,7 +1578,7 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   Anastasia => qr/^((Ana(stasia)?|Stac$E))$/, # Ana Stac$E
   Anderson => qr/^((An(ce|d($E|er(son)?|re))|Sonn$E))$/, # Ander And$E Sonn$E Ance Andre
   Andrea => qr/^(And($E|r(ea|ia)))$/, # Andria And$E
-  Andrew => qr/^((And($E|rew)|Drew))$/, # And$E Drew
+  Andrew => qr/^((And($E|re(as|i|w|y))|Drew))$/, # And$E Drew Andrei Andrey Andreas
   Angela => qr/^((Ang($E|el(a|i(ca|n[ae])))|Jane|Lena))$/, # Angelica Angelina Angeline Ang$E Jane Lena
   Anna => qr/^((Ann($E|a|e(tte)?)?|Hannah|Nan(a|c$E|n$E)?|Susanna))$/, # Ann Anne Ann$E Hannah Nan Nann$E Nanc$E Nana Susanna Annette
   Anselm => qr/^(An(ce|se(lm?)?))$/, # Anse Ance Ansel
@@ -1631,7 +1651,7 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   Celeste => qr/^((Cel(este|ia)|Less$E))$/, # Celia Less$E
   Celinda => qr/^((Celinda|L(ind($E|a)|ynn)))$/, # Linda Lind$E Lynn
   Charity => qr/^(Cha(rity|t))$/, # Chat
-  Charles => qr/^((Buck|C(arl|h(a(d|rl($E|es))|ick|uck))|Kar(el|l)))$/, # Buck Carl Chad Charl$E Chick Chuck Karl Karel
+  Charles => qr/^((Buck|C(arl|h(a(d|rl($E|es))|i(ck|p)|uck))|Kar(el|l)))$/, # Buck Carl Chad Charl$E Chick Chuck Karl Karel Chip
   Charlotte => qr/^((C(ar(lotta)?|har(lotte)?)|L(ett$E|o(ll$E|tt($E|a)))|Sherr$E))$/, # Car Carlotta Lett$E Lotta Lott$E Char Sherr$E Loll$E
   Chauncy => qr/^(Cha(n|uncy))$/, # Chan
   Chesley => qr/^(Che(sl($E|ey)|t))$/, # Chesl$E Chet
@@ -1737,11 +1757,12 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   Frances => qr/^((Ciss$E|F(an(n$E)?|ran(ces)?)|Sis))$/, # Fan Fann$E Fran Sis Ciss$E
   Francis => qr/^(Fran(cis|k($E|isek|lin)?|z))$/, # Frank Frank$E Frankisek Franklin Franz
   Frederica => qr/^((Fr(ed(a|d$E|erica|ricka)|ieda)|Ricka))$/, # Fredricka Freda Fredd$E Ricka Frieda
-  Frederick => qr/^(Fr(ed(d$E|erick|ric)?|i(sh|tz)))$/, # Fred Fredric Fredd$E Frish Fritz
+  Frederick => qr/^(Fr(ed(d$E|eri(ck|k)|ri[ck])?|i(sh|t[sz])))$/, # Fred Fredric Frederik Fredrik Fredd$E Frish Fritz Frits
   Fredonia => qr/^((Don(ia|na)|Fredonia))$/, # Donia Donna
   Gabriel => qr/^(Gab(b$E|e|riel))$/, # Gabe Gabb$E
   Gabrielle => qr/^((Ella|Gab(b$E|riell[ae])))$/, # Ella Gabb$E Gabriella
   Gabrilla => qr/^((Gabrilla|Rilla))$/, # Rilla
+  Gary => qr/^(Gar(ry|y))$/, # Garry
   Genevieve => qr/^((Eve|Gen(c$E|evieve)?|J(e(an|nn$E)|ins$E)|Neva))$/, # Genc$E Jins$E Jenn$E Eve Jean Gen Neva
   George => qr/^((George|Jorge))$/, # Jorge
   Georgia => qr/^(Ge(e|orgia(na)?))$/, # Georgiana Gee
@@ -1761,6 +1782,7 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   Harold => qr/^(Ha(l|nk|r(old|r$E)))$/, # Hal Harr$E Hank
   Harriet => qr/^(Ha(rriet|tt$E))$/, # Hatt$E
   Helena => qr/^((Aileen|E(ileen|l(aine|e(anor|na)|l(a|en(der)?)))|Helen[ae]?|Lena|Nell($E)?))$/, # Helen Aileen Eileen Elaine Eleanor Ellen Lena Nell Nell$E Helene Ella Elena Ellender
+  Hendrick => qr/^(Hen(drick|k))$/, # Henk
   Henrietta => qr/^((Ett($E|a)|H(ank|e(nrietta|tt$E))|Nett$E|Retta))$/, # Etta Hank Hett$E Nett$E Retta Ett$E
   Henry => qr/^(H(a(l|nk|rr$E)|en(ce|ry)?))$/, # Hal Hank Harr$E Hen Hence
   Hepsabah => qr/^(He(bsabeth|p(hsibah|s($E|ab(ah|el)|ibah))))$/, # Heps$E Hepsibah Hephsibah Hebsabeth Hepsabel
@@ -1837,7 +1859,7 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   Lecurgus => qr/^((Curg|Lecurgus))$/, # Curg
   Lemuel => qr/^(Lem(uel)?)$/, # Lem
   Leonard => qr/^(L(e(n(hart|n$E)?|o(n(ard)?)?)|ineau))$/, # Leo Leon Len Lenn$E Lineau Lenhart
-  Leonidas => qr/^(Leon(idas)?)$/, # Leon
+  Leonidas => qr/^(Leo(n(idas?)?)?)$/, # Leonida Leon Leo
   Leonora => qr/^((Elenor|L(e(e|onora)|oenore)|Nora))$/, # Loenore Elenor Nora Lee
   Leroy => qr/^((L(R|e(e|roy))|Roy))$/, # Lee Roy LR
   Leslie => qr/^(Les(lie|ter)?)$/, # Les Lester
@@ -1875,7 +1897,7 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   Manerva => qr/^((M(anerva|inerva)|Nerv($E|a)))$/, # Minerva Nerva Nerv$E
   Manoah => qr/^((Manoah|Noah))$/, # Noah
   Manuel => qr/^((Emanuel|Man(n$E|uel)))$/, # Emanuel Mann$E
-  Marcus => qr/^(Mar(cus|k))$/, # Mark
+  Marcus => qr/^(Mar(c(us)?|k))$/, # Mark Marc
   Margaret => qr/^((Dais$E|Gret(a|ta)|M(a(dge|gg$E|is$E|r(g($E|aret(ha|ta)?|e(r$E)?|o)|jor$E))|e(g(an)?|t(a|ta))|idge)|Peg(g$E)?|Rita))$/, # Dais$E Greta Madge Magg$E Mais$E Marge Margo Peg Meg Metta Midge Pegg$E Margaretha Meta Gretta Rita Marger$E Marjor$E Marg$E Margaretta Megan
   Margarita => qr/^((Marga(rita|uerite)|Rita))$/, # Rita Margauerite
   Marianna => qr/^((Anne?|M(ar($E|ia(n(n[ae])?)?)|ia)))$/, # Marian Ann Marianne Anne Mar$E Maria Mia
@@ -1925,11 +1947,13 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   Nathaniel => qr/^((Fannn$E|Jonathan|Nat(e|han(iel)?|t$E)?|Than))$/, # Jonathan Nat Natt$E Nathan Nate Than Fannn$E
   Nelson => qr/^(Nels(on)?)$/, # Nels
   Newton => qr/^(Newt(on)?)$/, # Newt
-  Nicholas => qr/^((Cla(as|es)|Nic(holas|k($E)?|odemus)))$/, # Nick Nick$E Claas Claes Nicodemus
+  Nicholas => qr/^((Cla(as|es)|Nic(holas|k($E)?|o(demus|las))))$/, # Nick Nick$E Nicolas Claas Claes Nicodemus
   Nicolena => qr/^(Ni(c(k$E|ol(e(n[ae])?|ina))|kk$E))$/, # Nicole Nikk$E Nick$E Nicolene Nicolina
+  Nikolai => qr/^(Ni(colay|kolai))$/, # Nicolay
   Ninell => qr/^(N(ett$E|inell))$/, # Nett$E
   Noel => qr/^((Knowell|No(el|well)))$/, # Nowell Knowell
   Norbert => qr/^((Bert|Norb($E|ert)))$/, # Bert Norb$E
+  Norman => qr/^(Norm(an)?)$/, # Norm
   Obadiah => qr/^((D(iah|yer)|Ob($E|adiah|ed?)))$/, # Diah Dyer Obe Obed Ob$E
   Obedience => qr/^((B(e(de|ed$E)|idd$E)|Obed(ience)?))$/, # Bidd$E Obed Bede Beed$E
   Oberon => qr/^(Ob($E|e(ron)?))$/, # Obe Ob$E
@@ -1981,12 +2005,13 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   Relief => qr/^((Leaf($E|a)|Relief))$/, # Leafa Leaf$E
   Reuben => qr/^(R(euben|ub($E|e)))$/, # Rube Rub$E
   Rhodella => qr/^((Della?|Rhod($E|a|ella)))$/, # Rhoda Rhod$E Dell Della
-  Richard => qr/^((Dick(on|son)?|Ric(h($E|ard)?|k($E)?)))$/, # Dick Rich Rick Rich$E Dickon Dickson Rick$E
-  Robert => qr/^((Bob(b$E)?|Dob(bin)?|Hob(kin)?|R(ob(b$E|ert|in)?|upert)))$/, # Dob Dobbin Bob Bobb$E Rob Robin Rupert Hob Hobkin Robb$E
+  Richard => qr/^((Dick(on|son)?|Ric(ardo|h($E|ard)?|k($E)?)))$/, # Dick Rich Rick Rich$E Dickon Dickson Rick$E Ricardo
+  Robert => qr/^((Bob(b$E)?|Dob(bin)?|Hob(kin)?|R(ob(b$E|erto?|in)?|upert)))$/, # Dob Dobbin Bob Bobb$E Roberto Rob Robin Rupert Hob Hobkin Robb$E
   Roberta => qr/^((B(ert($E)?|ird$E|obb$E)|Rob(b$E|erta)))$/, # Bert Bobb$E Robb$E Bert$E Bird$E
   Rodney => qr/^(Rod(d$E|ney)?)$/, # Rod Rodd$E
   Roger => qr/^((Hodge(kin)?|Ro(d(ger)?|ger?)))$/, # Hodge Hodgekin Rodger Roge Rod
-  Roland => qr/^((Lann$E|Naldo|Orlando|Ro(l(and|l($E|o))|n(n$E)?|wland)))$/, # Orlando Rowland Lann$E Rollo Roll$E Ron Ronn$E Naldo
+  Roland => qr/^((Lann$E|Orlando|Ro(l(and|l($E|o))|wland)))$/, # Orlando Rowland Lann$E Rollo Roll$E
+  Ronald => qr/^((Naldo|Ron(aldo?|n$E)?))$/, # Ron Ronn$E Naldo Ronaldo
   Rosabella => qr/^((Belle|Ro(s(a(b(ella|le))?|e)|z)))$/, # Rosable Belle Rosa Rose Roz
   Rosalyn => qr/^((Linda|Ro(s(a(l(inda|yn))?|e)|z)))$/, # Rosalinda Rosa Rose Linda Roz
   Roseanne => qr/^((Ann|Ro(s($E|e(ann[ae]?)?)|x($E|an(e|n[ae]))?|z)))$/, # Roseann Rose Ann Roz Ros$E Roseanna Rox Rox$E Roxanne Roxanna Roxane
@@ -2025,7 +2050,7 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   Tasha => qr/^(Tash($E|a)?)$/, # Tash Tash$E
   Temperance => qr/^(T(emp($E|erance)|ill$E))$/, # Temp$E Till$E
   Tennessee => qr/^(Tenn($E|essee))$/, # Tenn$E
-  Terrance => qr/^(Ter(ence|r($E|ance)))$/, # Terence Terr$E
+  Terrence => qr/^(Ter(ence|r($E|ance|ence)))$/, # Terrance Terence Terr$E
   Thaddeus => qr/^(T(ad|had(deus)?))$/, # Tad Thad
   Theodore => qr/^(T(ad|ed(d$E)?|heo(d(or(e|ick)|rick))?))$/, # Ted Theodrick Theodorick Tad Theo Tedd$E
   Theodosia => qr/^((Do(ra|sia)|Theo(do(ra|sia))?))$/, # Dosia Theo Theodora Dora
@@ -2114,6 +2139,7 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   Hannah => [qw<Joanna Susannah Anna>],
   Harold => [qw<Henry>],
   Helena => [qw<Eleanor>],
+  Hendrick => [qw<Henry>],
   Henry => [qw<Harold>],
   Hepsabah => [qw<Elizabeth Rosabella>],
   Honora => [qw<Eleanor>],
@@ -2150,13 +2176,15 @@ my $E= qr/(ie?|e?y)/; # phoenetic long 'E' for many name endings
   Montgomery => [qw<Lamont>],
   Nancy => [qw<Ann>],
   Nathaniel => [qw<Johnathan>],
+  Nikolai => [qw<Nicholas>],
   Obadiah => [qw<Jedediah>],
   Patience => [qw<Patricia>],
   Patrick => [qw<Peter>],
   Philinda => [qw<Belinda Linda Philinda>],
   Rodney => [qw<Roger Reginald Ronald>],
   Roger => [qw<Rodney>],
-  Roland => [qw<Orlando Reginald>],
+  Roland => [qw<Roland Orlando Reginald>],
+  Ronald => [qw<Roland Reginald>],
   Rosabella => [qw<Isabella Roseanne Rosarita Rosalyn>],
   Rosalyn => [qw<Rose Linda>],
   Roseanne => [qw<Rosabella Rosalyn Rosarita Anna>],
